package main

import "encoding/json"

type Task struct {
	// ID       int    `json:"id"`
	User     string `json:"user"`
	TaskType string `json:"task_type"`
	TaskId   string `json:"task_id"`
	Start    bool   `json:"start"`
	Stop     bool   `json:"stop"`
}

func QueryAllTask() ([]Task, error) {

	data, count, err := client.From("tasks").Select("*", "exact", false).
		Eq("start", "true").Neq("stop", "true").
		Execute()

	if err != nil {
		return nil, err
	}

	_ = count

	// fmt.Println(count, string(data))

	res := make([]Task, 0, count)

	if err := json.Unmarshal(data, &res); err != nil {
		return nil, err
	}

	return res, nil

}

func VerifyFollowerInDb(userId, followerId string) (bool, error) {

	_, count, err := client.From("followers").Select("*", "exact", false).Eq("user_id", userId).Eq("follower_id", followerId).Execute()

	if err != nil {
		return false, err
	}

	return count == 1, nil
}

func VerifyRetweeterInDb(tweetId, retweeter string) (bool, error) {

	_, count, err := client.From("retweeters").Select("*", "exact", false).Eq("tweet_id", tweetId).Eq("retweeter_id", retweeter).Execute()

	if err != nil {
		return false, err
	}

	return count == 1, nil
}

func AddTaskInsertOrUpdate(req AddTaskReq) error {

	task := Task{
		User:     req.User,
		TaskType: req.TaskType,
		TaskId:   req.TaskId,
		Start:    true,
		Stop:     false,
	}

	res, _, err := client.From("tasks").Insert(task, true, "", "representation", "").Execute()

	_ = res

	return err

}

func StopTaskUpdate(req AddTaskReq) error {

	//res, _, err := client.From("tasks").Insert(task, true, "", "representation", "").Execute()

	res, _, err := client.From("tasks").Update(&struct {
		Stop bool `json:"stop"`
	}{
		Stop: true,
	}, "", "exact").Eq("task_type", req.TaskType).Eq("task_id", req.TaskId).Execute()

	_ = res

	return err

}
